@@ -1,5 +1,5 @@
 package MaxMind::DB::Writer;
-$MaxMind::DB::Writer::VERSION = '0.050005';
+$MaxMind::DB::Writer::VERSION = '0.050006';
 use strict;
 use warnings;
 
@@ -19,7 +19,7 @@ MaxMind::DB::Writer - Create MaxMind DB database files
 
 =head1 VERSION
 
-version 0.050005
+version 0.050006
 
 =head1 SYNOPSIS
 
@@ -55,17 +55,36 @@ This distribution contains the code necessary to write L<MaxMind DB database
 files|http://maxmind.github.io/MaxMind-DB/>. See L<MaxMind::DB::Writer::Tree>
 for API docs.
 
+=head1 WINDOWS SUPPORT
+
+This distribution does not currently work on Windows. Reasonable patches for
+Windows support are very welcome. You will probably need to start by making
+L<Math::Int128> work on Windows, since we use that module's C API for dealing
+with 128-bit integers to represent IPv6 addresses numerically.
+
+=head1 SUPPORT
+
+Please report all issues with this code using the GitHub issue tracker at
+L<https://github.com/maxmind/MaxMind-DB-Writer-perl/issues>.
+
+We welcome patches as pull requests against our GitHub repository at
+L<https://github.com/maxmind/MaxMind-DB-Writer-perl>.
+
 =head1 AUTHORS
 
 =over 4
 
 =item *
 
-Dave Rolsky <autarch@urth.org>
+Olaf Alders <oalders@maxmind.com>
 
 =item *
 
-Olaf Alders <olaf@wundercounter.com>
+Greg Oschwald <goschwald@maxmind.com>
+
+=item *
+
+Dave Rolsky <drolsky@maxmind.com>
 
 =back
 
